==> haskell-tasty-smallcheck-0.8.2-847.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-smallcheck
version:              0.8.2
visibility:           public
id:                   tasty-smallcheck-0.8.2-EbAclBjD1imFmOvmdK1dnL
key:                  tasty-smallcheck-0.8.2-EbAclBjD1imFmOvmdK1dnL
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/feuerbach/tasty
synopsis:             SmallCheck support for the Tasty test framework.
description:          SmallCheck support for the Tasty test framework.
category:             Testing
abi:                  b61929c5f4c357c9a8b60730db424f95
exposed:              True
exposed-modules:      Test.Tasty.SmallCheck
import-dirs:
    /usr/lib/ghc-9.6.7.20250817/site-local/tasty-smallcheck-0.8.2

library-dirs:
    /usr/lib/ghc-9.6.7.20250817/site-local/tasty-smallcheck-0.8.2

library-dirs-static:
    /usr/lib/ghc-9.6.7.20250817/site-local/tasty-smallcheck-0.8.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-smallcheck
hs-libraries:         HStasty-smallcheck-0.8.2-EbAclBjD1imFmOvmdK1dnL
depends:
    base-4.18.3.0 optparse-applicative-0.18.1.0-KQP8jsJAas2R1tawxIFsA
    smallcheck-1.2.1.1-6OcpELJLz9P1Pi9HbM8JEf
    tagged-0.8.9-HMh4qZxoofeBZ9IcdInbXO
    tasty-1.5.2-DYWdVUlVmZ2GEsYE1QJgVb

haddock-interfaces:
    /usr/share/doc/haskell-tasty-smallcheck/html/tasty-smallcheck.haddock

haddock-html:         /usr/share/doc/haskell-tasty-smallcheck/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-smallcheck-0.8.2-847.3-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-smallcheck
version:              0.8.2
visibility:           public
id:                   tasty-smallcheck-0.8.2-46Q4WFaNcHwIOESu4aT9XS
key:                  tasty-smallcheck-0.8.2-46Q4WFaNcHwIOESu4aT9XS
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/feuerbach/tasty
synopsis:             SmallCheck support for the Tasty test framework.
description:          SmallCheck support for the Tasty test framework.
category:             Testing
abi:                  9f62aace50ef5248fa49c0b3e6920790
exposed:              True
exposed-modules:      Test.Tasty.SmallCheck
import-dirs:
    /usr/lib/ghc-9.6.7.20250817/site-local/tasty-smallcheck-0.8.2

library-dirs:
    /usr/lib/ghc-9.6.7.20250817/site-local/tasty-smallcheck-0.8.2

library-dirs-static:
    /usr/lib/ghc-9.6.7.20250817/site-local/tasty-smallcheck-0.8.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-smallcheck
hs-libraries:         HStasty-smallcheck-0.8.2-46Q4WFaNcHwIOESu4aT9XS
depends:
    base-4.18.3.0 optparse-applicative-0.18.1.0-BYVre8yzbBOKektbxJ0fjC
    smallcheck-1.2.1.1-6OcpELJLz9P1Pi9HbM8JEf
    tagged-0.8.9-HMh4qZxoofeBZ9IcdInbXO
    tasty-1.5.2-1URN3hwk0ElEsqpxhMRHaT

haddock-interfaces:
    /usr/share/doc/haskell-tasty-smallcheck/html/tasty-smallcheck.haddock

haddock-html:         /usr/share/doc/haskell-tasty-smallcheck/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
